# Generated by Django 3.2.8 on 2021-10-28 14:47

from django.db import migrations, models
import django.db.models.deletion
import django_rest_admin.model_field


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RouteExec',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('route', models.TextField(blank=True, help_text='the route name. eg: /Danwei', null=True)),
                ('table_big_name', models.TextField(blank=True, help_text='the model name of a table. eg: Danwei', null=True)),
                ('inspected_from_db', models.IntegerField(blank=True, help_text='是否需要将库中表导入为django的model。1，0. eg: 0 ', null=True)),
                ('table_name', models.TextField(blank=True, help_text='the table name. eg: danwei. ONLY needed if inspected_from_db=1', null=True)),
                ('import_py_code', models.TextField(blank=True, help_text='needed if the model need to import from somewhere else. eg:from django.auth import User', null=True)),
                ('desc', models.TextField(blank=True, help_text='表功能描述. eg: this is the rest description', null=True)),
                ('foreign_key_id', django_rest_admin.model_field.JSONField(blank=True, help_text='外键定义.关联删除属性：CASCADE-关联删除, SET_NULL-字段变空, DO_NOTHING-不做操作. eg: {"user":["User", "CASCADE"], "article":["Article", "SET_NULL"]}', null=True)),
                ('foreign_key_ro', django_rest_admin.model_field.JSONField(blank=True, help_text='外键关联的只读内容. eg: {"article_name":"article.name"}', null=True)),
                ('foreign_slug_kf', django_rest_admin.model_field.JSONField(blank=True, help_text='一对多外键关联的字段列表. eg: {"StatKucun_wuliao": ["kucun", "jinjia"]}', null=True)),
                ('ordering_fields', django_rest_admin.model_field.JSONField(blank=True, help_text='可用排序字段，数组，每个项是字符串. eg:["id", "name"]', null=True)),
                ('ordering', django_rest_admin.model_field.JSONField(blank=True, help_text='默认排序字段，数组，每个项是字符串. eg:["id", "name"]', null=True)),
                ('no_need_login', models.IntegerField(blank=True, help_text='访问是否需要登陆。1，0. eg: 0 ', null=True)),
                ('search_fields', django_rest_admin.model_field.JSONField(blank=True, help_text='可用排序字段，数组，每个项是字符串. eg: ["name", "zhujima"]', null=True)),
                ('filter_keys', django_rest_admin.model_field.JSONField(blank=True, help_text='过滤项. eg: [{"filter_name": "name", "field_name": "name", "filter_type": "text", "lookup_expr": "icontains"}]', null=True)),
                ('model_object_list', django_rest_admin.model_field.JSONField(blank=True, help_text='可显示字段. eg: ["id", "name", "daima"]', null=True)),
                ('params', django_rest_admin.model_field.JSONField(blank=True, help_text='AUTO-GENERATED FIELD. DO NOT EDIT THIS MANUALLY.', null=True)),
            ],
            options={
                'verbose_name_plural': 'table-REST-CRUD',
                'db_table': 'rest_admin_table_crud',
                'managed': True,
            },
        ),
        migrations.CreateModel(
            name='ComputedField',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('func_text', django_rest_admin.model_field.CodeField(blank=True, help_text='py函数.eg: def jine(self):return 0', null=True)),
                ('route_exec', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_rest_admin.routeexec')),
            ],
            options={
                'verbose_name_plural': '计算函数字段',
                'db_table': 'rest_admin_table_crud_computed_field',
                'managed': True,
            },
        ),
    ]
